ini

package module
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 10 Imported by: 0

README

INI

Package ini provides functions for loading and saving INI configurations.

Feature

  • TODO.

Usage

  • TODO.

Note

  • TODO.

Documentation

Overview

Package ini provides functions for loading and saving INI configurations.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Load

func Load(filename string, out any) error

Load loads the INI configuration from the named file and parses it into T.

func LoadBytes

func LoadBytes(data []byte, out any) error

LoadBytes parses the INI configuration from the data and populates T.

func LoadReader

func LoadReader(reader io.Reader, out any) error

LoadReader reads the INI configuration from the reader and parses it into T.

Types

This section is empty.

Jump to